==> econkit-0.0.9.tar.gz: econkit-0.0.9/README.md <==
<h1>EconKit Package</h1>

<p>This is a detailed description of the EconKit package. It provides advanced tools and functions for econometric analysis, tailored to the needs of researchers, students, and professionals in economics and finance.</p>

<h2>Installation</h2>

<p>To install the EconKit package, run the following command:</p>

<pre><code>pip install econkit</code></pre>

<h2>Usage</h2>

<p>Here's how to use the main functions in the package:</p>

<pre><code>from EconKit import descriptives
from EconKit import correlation

descriptives(dataframe)
correlation(dataframe, method="Pearson", p="T")
</code></pre>

<h2>Features</h2>

<ul>
  <li>Comprehensive econometric analysis tools</li>
  <li>Support for various correlation methods</li>
  <li>User-friendly interface for complex statistical operations</li>
</ul>

<h2>Requirements</h2>

<p>The package requires the following Python libraries:</p>

<ul>
  <li>Numpy</li>
  <li>Pandas</li>
  <li>Scipy</li>
</ul>

<h2>Contributing</h2>

<p>We welcome contributions to the EconKit package. Please read the contributing guidelines before submitting your pull requests.</p>

<h2>License</h2>

<p>This project is licensed under the BSD 3-Clause License - see the <a href="LICENSE">LICENSE</a> file for details.</p>

<h2>Acknowledgments</h2>

<p>Special thanks to all contributors and supporters of the project.</p>

<h2>Contact</h2>

<p>For questions or support, please contact <a href="mailto:contact@stfanstavrianos.eu">contact@stfanstavrianos.eu</a>.</p>

==> econkit-0.1.0.tar.gz: econkit-0.1.0/README.md <==
<h1>EconKit Package</h1>

<p>This is a detailed description of the EconKit package. It provides advanced tools and functions for econometric analysis, tailored to the needs of researchers, students, and professionals in economics and finance.</p>

<h2>Installation</h2>

<p>To install the EconKit package, run the following command:</p>

<pre><code>pip install econkit</code></pre>

<h2>Usage</h2>

<p>Here's how to use the main functions in the package:</p>

<pre><code>### Import ###

from econkit import descriptives
from econkit import correlation
from econkit import stock
from econkit import table


### Run Code ###
Returns = table('Returns', MCD, SBUX, PFE, AMGN, AXP)
stock('TSLA', '01-01-2000', '01-01-2024', '1d')
descriptives(dataframe)
correlation(dataframe, method="Pearson", p="T")
</code></pre>

<h2>Features</h2>

<ul>
  <li>Comprehensive econometric analysis tools</li>
  <li>Support for various correlation methods</li>
  <li>User-friendly interface for complex statistical operations</li>
</ul>

<h2>Requirements</h2>

<p>The package requires the following Python libraries:</p>

<ul>
  <li>Numpy</li>
  <li>Pandas</li>
  <li>Scipy</li>
</ul>

<h2>Contributing</h2>

<p>We welcome contributions to the EconKit package. Please read the contributing guidelines before submitting your pull requests.</p>

<h2>License</h2>

<p>This project is licensed under the BSD 3-Clause License - see the <a href="LICENSE">LICENSE</a> file for details.</p>

<h2>Acknowledgments</h2>

<p>Special thanks to all contributors and supporters of the project.</p>

<h2>Contact</h2>

<p>For questions or support, please contact <a href="mailto:contact@stfanstavrianos.eu">contact@stfanstavrianos.eu</a>.</p>
